@@ -110,7 +110,12 @@ static lookup_node _lookup_links[] =
 	{ "setloginuser", 0 },
 	{ "_getstatistics", 0 },
 	{ "_invalidatecache", 0 },
-	{ "_suspend", 0 }
+	{ "_suspend", 0 },
+
+	{ "dns_proxy", 0 },
+	
+	{ "getaddrinfo", 0 },
+	{ "getnameinfo", 0 }
 };
 
 #define LOOKUP_NPROCS  (sizeof(_lookup_links)/sizeof(_lookup_links[0]))
